@@ -1,15 +1,103 @@
-package Net::Fritz::Action;
 use strict;
 use warnings;
+# Copyright (C) 2015  Christian Garbs <mitch@cgarbs.de>
+# Licensed under GNU GPL v2 or later.
+
+package Net::Fritz::Action;
+# ABSTRACT: represents a TR064 action
+$Net::Fritz::Action::VERSION = 'v0.0.2';
 
 use Moo;
 
 with 'Net::Fritz::IsNoError';
 
+
+has xmltree      => ( is => 'ro' );
+
+    
+has name         => ( is => 'lazy', init_arg => undef );
+
+sub _build_name {
+    my $self = shift;
+    return $self->xmltree->{name}->[0];
+}
+
+
+has args_in      => ( is => 'lazy', init_arg => undef );
+
+sub _build_args_in {
+    my $self = shift;
+    my @args;
+
+    # TODO convert to grep
+    foreach my $arg (@{$self->xmltree->{argumentList}->[0]->{argument}}) {
+	if ($arg->{direction}->[0] eq 'in') {
+	    push @args, $arg->{name}->[0];
+	}
+    }
+
+    return \@args;
+}
+
+
+has args_out     => ( is => 'lazy', init_arg => undef );
+
+sub _build_args_out {
+    my $self = shift;
+    my @args;
+
+    # TODO convert to grep
+    foreach my $arg (@{$self->xmltree->{argumentList}->[0]->{argument}}) {
+	if ($arg->{direction}->[0] eq 'out') {
+	    push @args, $arg->{name}->[0];
+	}
+    }
+
+    return \@args;
+}
+
+
+sub BUILDARGS {
+    my ( $class, @args ) = @_;
+
+    unshift @args, "xmltree" if @args % 2 == 1;
+
+    return { @args };
+};
+
+
+sub dump {
+    my $self = shift;
+
+    my $indent = shift;
+    $indent = '' unless defined $indent;
+
+    my $text = "${indent}Net::Fritz::Action:\n";
+    $indent .= '  ';
+    $text .= "${indent}name     = " . $self->name     . "\n";
+    $text .= "${indent}args_in  = " . join(', ', @{$self->args_in})  . "\n";
+    $text .= "${indent}args_out = " . join(', ', @{$self->args_out}) . "\n";
+
+    return $text;
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Fritz::Action - represents a TR064 action
 
+=head1 VERSION
+
+version v0.0.2
+
 =head1 SYNOPSIS
 
     my $fritz    = Net::Fritz::Box->new();
@@ -35,71 +123,22 @@ A complex hashref containing most information about this
 L<Net::Fritz::Action>.  This is the parsed form of the part from the
 L<Net::Fritz::Service/scpd> XML that describes this action.
 
-=cut
-
-has xmltree      => ( is => 'ro' );
-
 =head2 name
 
 The name of this action as a string.  This is used to identify the
 action in a L<Net::Fritz::Service/call>.
 
-=cut
-    
-has name         => ( is => 'lazy', init_arg => undef );
-
-sub _build_name {
-    my $self = shift;
-    return $self->xmltree->{name}->[0];
-}
-
 =head2 args_in
 
 An arrayref containing the names of all input parameters for this
 action.  These parameters must be present in a L<Net::Fritz::Service/call>.
 
-=cut
-
-has args_in      => ( is => 'lazy', init_arg => undef );
-
-sub _build_args_in {
-    my $self = shift;
-    my @args;
-
-    # TODO convert to grep
-    foreach my $arg (@{$self->xmltree->{argumentList}->[0]->{argument}}) {
-	if ($arg->{direction}->[0] eq 'in') {
-	    push @args, $arg->{name}->[0];
-	}
-    }
-
-    return \@args;
-}
-
 =head2 args_out
 
 An arrayref containing the names of all output parameters of this
 action.  These parameters will be present in the
 L<Net::Fritz::Data/data> response to a L<Net::Fritz::Service/call>.
 
-=cut
-
-has args_out     => ( is => 'lazy', init_arg => undef );
-
-sub _build_args_out {
-    my $self = shift;
-    my @args;
-
-    # TODO convert to grep
-    foreach my $arg (@{$self->xmltree->{argumentList}->[0]->{argument}}) {
-	if ($arg->{direction}->[0] eq 'out') {
-	    push @args, $arg->{name}->[0];
-	}
-    }
-
-    return \@args;
-}
-
 =head2 error
 
 See L<Net::Fritz::IsNoError/error>.
@@ -123,15 +162,7 @@ action information in parsed XML format
 With only one parameter (in fact: any odd value of parameters), the
 first parameter is automatically mapped to I<xmltree>.
 
-=cut
-
-sub BUILDARGS {
-    my ( $class, @args ) = @_;
-
-    unshift @args, "xmltree" if @args % 2 == 1;
-
-    return { @args };
-};
+=for Pod::Coverage BUILDARGS
 
 =head2 dump(I<indent>)
 
@@ -140,44 +171,34 @@ Useful for debugging purposes, printing or logging.  The optional
 parameter I<indent> is used for indentation of the output by
 prepending it to every line.
 
-=cut
-
-sub dump {
-    my $self = shift;
-
-    my $indent = shift;
-    $indent = '' unless defined $indent;
-
-    my $text = "${indent}Net::Fritz::Action:\n";
-    $indent .= '  ';
-    $text .= "${indent}name     = " . $self->name     . "\n";
-    $text .= "${indent}args_in  = " . join(', ', @{$self->args_in})  . "\n";
-    $text .= "${indent}args_out = " . join(', ', @{$self->args_out}) . "\n";
-
-    return $text;
-}
-
 =head2 errorcheck
 
 See L<Net::Fritz::IsNoError/errorcheck>.
 
-=head1 COPYRIGHT
-
-Copyright (C) 2015 by  Christian Garbs <mitch@cgarbs.de>
-
-=head1 LICENSE
-
-Licensed under GNU GPL v2 or later, see <http://www.gnu.org/licenses/gpl-2.0-standalone.html>
-
-=head1 AUTHOR
-
-Christian Garbs <mitch@cgarbs.de>
-
 =head1 SEE ALSO
 
 See L<Net::Fritz> for general information about this package,
 especially L<Net::Fritz/INTERFACE> for links to the other classes.
 
-=cut
+=head1 AUTHOR
 
-1;
+Christian Garbs <mitch@cgarbs.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2016 Christian Garbs
+
+This program is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the Free
+Software Foundation, either version 2 of the License, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+more details.
+
+You should have received a copy of the GNU General Public License along
+with this program. If not, see <http://www.gnu.org/licenses/>.
+
+=cut
