@@ -1,6 +1,11 @@
-package Net::Fritz::Device;
 use strict;
 use warnings;
+# Copyright (C) 2015  Christian Garbs <mitch@cgarbs.de>
+# Licensed under GNU GPL v2 or later.
+
+package Net::Fritz::Device;
+# ABSTRACT: represents a TR064 device
+$Net::Fritz::Device::VERSION = 'v0.0.2';
 
 use Net::Fritz::Data;
 use Net::Fritz::Error;
@@ -10,10 +15,216 @@ use Moo;
 
 with 'Net::Fritz::IsNoError';
 
+
+has fritz        => ( is => 'ro' );
+
+
+has xmltree      => ( is => 'ro' );
+
+
+has service_list => ( is => 'lazy', init_arg => undef );
+
+sub _build_service_list {
+    my $self = shift;
+    my $xml  = $self->xmltree;
+    my @services;
+
+    if (exists $xml->{serviceList}) {
+	foreach my $service (@{$xml->{serviceList}->[0]->{service}}) {
+	    push @services, Net::Fritz::Service->new(
+		xmltree => $service,
+		fritz   => $self->fritz
+		);
+	}
+    }
+
+    return \@services;
+}
+
+
+has device_list  => ( is => 'lazy', init_arg => undef );
+
+sub _build_device_list {
+    my $self = shift;
+    my $xml  = $self->xmltree;
+    my @devices;
+
+    if (exists $xml->{deviceList}) {
+	foreach my $device (@{$xml->{deviceList}->[0]->{device}}) {
+	    push @devices, Net::Fritz::Device->new(
+		xmltree => $device,
+		fritz   => $self->fritz
+		);
+	}
+    }
+
+    return \@devices;
+}
+
+
+has attributes   => ( is => 'lazy', init_arg => undef );
+
+use constant ATTRIBUTES => qw(
+deviceType
+friendlyName
+manufacturer
+manufacturerURL
+modelDescription
+modelName
+modelNumber
+modelURL
+UDN
+presentationURL
+);
+
+sub _build_attributes {
+    my $self = shift;
+    my $xml  = $self->xmltree;
+    my $attributes = {};
+
+    for my $attr (ATTRIBUTES) {
+	if (exists $xml->{$attr}) {
+	    $attributes->{$attr} = $xml->{$attr}->[0];
+	}
+    }
+
+    return $attributes;
+}
+
+
+sub get_service {
+    my $self = shift;
+    my $type = shift;
+
+    foreach my $service (@{$self->service_list}) {
+	if ($service->serviceType eq $type) {
+	    return $service;
+	}
+    }
+
+    foreach my $device (@{$self->device_list}) {
+	my $service = $device->get_service($type);
+	if (! $service->error) {
+	    return $service;
+	}
+    }
+    
+    return Net::Fritz::Error->new('service not found');
+}
+
+
+sub find_service {
+    my $self = shift;
+    my $type = shift;
+
+    foreach my $service (@{$self->service_list}) {
+	if ($service->serviceType =~ /$type/) {
+	    return $service;
+	}
+    }
+
+    foreach my $device (@{$self->device_list}) {
+	my $service = $device->find_service($type);
+	if (! $service->error) {
+	    return $service;
+	}
+    }
+
+    return Net::Fritz::Error->new('service not found');
+}
+
+
+sub find_service_names {
+    my $self = shift;
+    my $type = shift;
+
+    my @found = ();
+
+    foreach my $service (@{$self->service_list}) {
+	if ($service->serviceType =~ /$type/) {
+	    push @found, $service;
+	}
+    }
+
+    foreach my $device (@{$self->device_list}) {
+	my $data = $device->find_service_names($type);
+	push @found, @{$data->data};
+    }
+
+    return Net::Fritz::Data->new(\@found);
+}
+
+
+sub find_device {
+    my $self = shift;
+    my $type = shift;
+
+    foreach my $device (@{$self->device_list}) {
+	if ($device->attributes->{deviceType} eq $type) {
+	    return $device;
+	}
+    }
+    
+    foreach my $device (@{$self->device_list}) {
+	my $device = $device->find_device($type);
+	if (! $device->error) {
+	    return $device;
+	}
+    }
+    
+    return Net::Fritz::Error->new( 'device not found' );
+}
+
+
+sub dump {
+    my $self = shift;
+
+    my $indent = shift;
+    $indent = '' unless defined $indent;
+
+    my $text = "${indent}Net::Fritz::Device:\n";
+    $indent .= '  ';
+    $text .= "${indent}modelName       = " . $self->attributes->{modelName} . "\n";
+    $text .= "${indent}presentationURL = " . $self->attributes->{presentationURL} . "\n" if defined $self->attributes->{presentationURL};
+
+    my @service_list = @{$self->service_list};
+    if (@service_list) {
+	$text .= "${indent}subservices    = {\n";
+	foreach my $service (@service_list) {
+	    $text .= $service->dump($indent . '  ');
+	}
+	$text .= "${indent}}\n";
+    }
+
+    my @device_list = @{$self->device_list};
+    if (@device_list) {
+	$text .= "${indent}subdevices      = {\n";
+	foreach my $device (@device_list) {
+	    $text .= $device->dump($indent . '  ');
+	}
+	$text .= "${indent}}\n";
+    }
+
+    return $text;
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Fritz::Device - represents a TR064 device
 
+=head1 VERSION
+
+version v0.0.2
+
 =head1 SYNOPSIS
 
     my $fritz    = Net::Fritz::Box->new();
@@ -48,72 +259,22 @@ L<Net::Fritz::Device>.
 A L<Net::Fritz::Box> instance containing the current configuration
 information (device address, authentication etc.).
 
-=cut
-
-has fritz        => ( is => 'ro' );
-
 =head2 xmltree
 
 A complex hashref containing all information about this
 L<Net::Fritz::Device>.  This is the parsed form of the TR064 XML which
 describes the device, it's subdevices and L<Net::Fritz::Service>s.
 
-=cut
-
-has xmltree      => ( is => 'ro' );
-
 =head2 service_list
 
 An arrayref of all L<Net::Fritz::Service>s that are available on this
 device.
 
-=cut
-
-has service_list => ( is => 'lazy', init_arg => undef );
-
-sub _build_service_list {
-    my $self = shift;
-    my $xml  = $self->xmltree;
-    my @services;
-
-    if (exists $xml->{serviceList}) {
-	foreach my $service (@{$xml->{serviceList}->[0]->{service}}) {
-	    push @services, Net::Fritz::Service->new(
-		xmltree => $service,
-		fritz   => $self->fritz
-		);
-	}
-    }
-
-    return \@services;
-}
-
 =head2 device_list
 
 An arrayref of all subdevices (L<Net::Fritz::Device>) that are
 available on this device.
 
-=cut
-
-has device_list  => ( is => 'lazy', init_arg => undef );
-
-sub _build_device_list {
-    my $self = shift;
-    my $xml  = $self->xmltree;
-    my @devices;
-
-    if (exists $xml->{deviceList}) {
-	foreach my $device (@{$xml->{deviceList}->[0]->{device}}) {
-	    push @devices, Net::Fritz::Device->new(
-		xmltree => $device,
-		fritz   => $self->fritz
-		);
-	}
-    }
-
-    return \@devices;
-}
-
 =head2 attributes
 
 A hashref that contains the most important information from the XML
@@ -146,37 +307,6 @@ XML:
 
 =back
 
-=cut
-
-has attributes   => ( is => 'lazy', init_arg => undef );
-
-use constant ATTRIBUTES => qw(
-deviceType
-friendlyName
-manufacturer
-manufacturerURL
-modelDescription
-modelName
-modelNumber
-modelURL
-UDN
-presentationURL
-);
-
-sub _build_attributes {
-    my $self = shift;
-    my $xml  = $self->xmltree;
-    my $attributes = {};
-
-    for my $attr (ATTRIBUTES) {
-	if (exists $xml->{$attr}) {
-	    $attributes->{$attr} = $xml->{$attr}->[0];
-	}
-    }
-
-    return $attributes;
-}
-
 =head2 error
 
 See L<Net::Fritz::IsNoError/error>.
@@ -211,28 +341,6 @@ service in the order they are listed in the device XML, depth first.
 
 If no matching service is found, a L<Net::Fritz::Error> is returned.
 
-=cut
-
-sub get_service {
-    my $self = shift;
-    my $type = shift;
-
-    foreach my $service (@{$self->service_list}) {
-	if ($service->serviceType eq $type) {
-	    return $service;
-	}
-    }
-
-    foreach my $device (@{$self->device_list}) {
-	my $service = $device->get_service($type);
-	if (! $service->error) {
-	    return $service;
-	}
-    }
-    
-    return Net::Fritz::Error->new('service not found');
-}
-
 =head2 find_service(I<regexp>)
 
 Returns the L<Net::Fritz::Service> whose
@@ -243,28 +351,6 @@ service in the order they are listed in the device XML, depth first.
 
 If no matching service is found, a L<Net::Fritz::Error> is returned.
 
-=cut
-
-sub find_service {
-    my $self = shift;
-    my $type = shift;
-
-    foreach my $service (@{$self->service_list}) {
-	if ($service->serviceType =~ /$type/) {
-	    return $service;
-	}
-    }
-
-    foreach my $device (@{$self->device_list}) {
-	my $service = $device->find_service($type);
-	if (! $service->error) {
-	    return $service;
-	}
-    }
-
-    return Net::Fritz::Error->new('service not found');
-}
-
 =head2 find_service_names(I<regexp>)
 
 Returns all L<Net::Fritz::Service>s whose
@@ -277,28 +363,6 @@ The resulting arrayref is wrapped in a L<Net::Fritz::Data> to allow
 L<error checking|Net::Fritz::IsNoError>.  (Although no error should
 ever occur, an an empty list is returned if nothing matched.)
 
-=cut
-
-sub find_service_names {
-    my $self = shift;
-    my $type = shift;
-
-    my @found = ();
-
-    foreach my $service (@{$self->service_list}) {
-	if ($service->serviceType =~ /$type/) {
-	    push @found, $service;
-	}
-    }
-
-    foreach my $device (@{$self->device_list}) {
-	my $data = $device->find_service_names($type);
-	push @found, @{$data->data};
-    }
-
-    return Net::Fritz::Data->new(\@found);
-}
-
 =head2 find_device(I<name>)
 
 Returns the L<Net::Fritz::Device> subdevice whose I<deviceType> equals
@@ -310,28 +374,6 @@ first.
 
 If no matching device is found, a L<Net::Fritz::Error> is returned.
 
-=cut
-
-sub find_device {
-    my $self = shift;
-    my $type = shift;
-
-    foreach my $device (@{$self->device_list}) {
-	if ($device->attributes->{deviceType} eq $type) {
-	    return $device;
-	}
-    }
-    
-    foreach my $device (@{$self->device_list}) {
-	my $device = $device->find_device($type);
-	if (! $device->error) {
-	    return $device;
-	}
-    }
-    
-    return Net::Fritz::Error->new( 'device not found' );
-}
-
 =head2 dump(I<indent>)
 
 Returns some preformatted multiline information about the object.
@@ -343,40 +385,6 @@ Recursively descends into subdevices and services, so dumping the root
 device of a L<Net::Fritz::Box/discover> should show everything that is
 available.
 
-=cut
-
-sub dump {
-    my $self = shift;
-
-    my $indent = shift;
-    $indent = '' unless defined $indent;
-
-    my $text = "${indent}Net::Fritz::Device:\n";
-    $indent .= '  ';
-    $text .= "${indent}modelName       = " . $self->attributes->{modelName} . "\n";
-    $text .= "${indent}presentationURL = " . $self->attributes->{presentationURL} . "\n" if defined $self->attributes->{presentationURL};
-
-    my @service_list = @{$self->service_list};
-    if (@service_list) {
-	$text .= "${indent}subservices    = {\n";
-	foreach my $service (@service_list) {
-	    $text .= $service->dump($indent . '  ');
-	}
-	$text .= "${indent}}\n";
-    }
-
-    my @device_list = @{$self->device_list};
-    if (@device_list) {
-	$text .= "${indent}subdevices      = {\n";
-	foreach my $device (@device_list) {
-	    $text .= $device->dump($indent . '  ');
-	}
-	$text .= "${indent}}\n";
-    }
-
-    return $text;
-}
-
 =head2 errorcheck
 
 See L<Net::Fritz::IsNoError/errorcheck>.
@@ -392,23 +400,30 @@ B<TODO:> Rename L</find_service_names> to something like
 L</find_all_service> as it's basically L</find_service> with multiple
 results.  It does not return service names but services.
 
-=head1 COPYRIGHT
-
-Copyright (C) 2015 by  Christian Garbs <mitch@cgarbs.de>
-
-=head1 LICENSE
-
-Licensed under GNU GPL v2 or later, see <http://www.gnu.org/licenses/gpl-2.0-standalone.html>
-
-=head1 AUTHOR
-
-Christian Garbs <mitch@cgarbs.de>
-
 =head1 SEE ALSO
 
 See L<Net::Fritz> for general information about this package,
 especially L<Net::Fritz/INTERFACE> for links to the other classes.
 
-=cut
+=head1 AUTHOR
 
-1;
+Christian Garbs <mitch@cgarbs.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2016 Christian Garbs
+
+This program is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the Free
+Software Foundation, either version 2 of the License, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+more details.
+
+You should have received a copy of the GNU General Public License along
+with this program. If not, see <http://www.gnu.org/licenses/>.
+
+=cut
