@@ -1,16 +1,59 @@
-package Net::Fritz::Error;
 use strict;
 use warnings;
+# Copyright (C) 2015  Christian Garbs <mitch@cgarbs.de>
+# Licensed under GNU GPL v2 or later.
+
+package Net::Fritz::Error;
+# ABSTRACT: wraps any error from the L<Net::Fritz> modules
+$Net::Fritz::Error::VERSION = 'v0.0.2';
 
 # TODO: use a global configuration option to make every call to
 #       Net::Fritz::Error->new an immediately fatal error?
 
 use Moo;
 
+
+has error => ( is => 'ro', default => 'generic error' );
+
+
+sub BUILDARGS {
+    my ( $class, @args ) = @_;
+    
+    unshift @args, "error" if @args % 2 == 1;
+    
+    return { @args };
+};
+
+
+sub errorcheck {
+    my $self = shift;
+    die "Net::Fritz::Error: " . $self->error. "\n";
+}
+
+
+sub dump {
+    my $self = shift;
+
+    return "Net::Fritz::Error: " . $self->error . "\n";
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Fritz::Error - wraps any error from the L<Net::Fritz> modules
 
+=head1 VERSION
+
+version v0.0.2
+
 =head1 SYNOPSIS
 
     $root_device = Net::Fritz::Box->new->discover;
@@ -51,10 +94,6 @@ L<Net::Fritz::Service> object instead).
 Contains the error message as a string.  Don't set this to anything
 resembling false or you will trick your tests.
 
-=cut
-
-has error => ( is => 'ro', default => 'generic error' );
-
 =head1 METHODS
 
 =head2 new
@@ -74,57 +113,41 @@ set the error message
 With only one parameter (in fact: any odd value of parameters), the
 first parameter is automatically mapped to I<error>.
 
-=cut
-
-sub BUILDARGS {
-    my ( $class, @args ) = @_;
-    
-    unshift @args, "error" if @args % 2 == 1;
-    
-    return { @args };
-};
+=for Pod::Coverage BUILDARGS
 
 =head2 errorcheck
-    
+
 Immediately C<die()>, printing the error text.
 
-=cut
-
-sub errorcheck {
-    my $self = shift;
-    die "Net::Fritz::Error: " . $self->error. "\n";
-}
-
 =head2 dump
 
 Returns some preformatted information about the object.  Useful for
 debugging purposes, printing or logging.
 
-=cut
-
-sub dump {
-    my $self = shift;
-
-    return "Net::Fritz::Error: " . $self->error . "\n";
-}
-
-=head1 COPYRIGHT
-
-Copyright (C) 2015 by  Christian Garbs <mitch@cgarbs.de>
-
-=head1 LICENSE
-
-Licensed under GNU GPL v2 or later, see <http://www.gnu.org/licenses/gpl-2.0-standalone.html>
-
-=head1 AUTHOR
-
-Christian Garbs <mitch@cgarbs.de>
-
 =head1 SEE ALSO
 
 See L<Net::Fritz> for general information about this package,
 especially L<Net::Fritz/INTERFACE> for links to the other classes.
 
-=cut
+=head1 AUTHOR
 
-1;
+Christian Garbs <mitch@cgarbs.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2016 Christian Garbs
+
+This program is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the Free
+Software Foundation, either version 2 of the License, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+more details.
+
+You should have received a copy of the GNU General Public License along
+with this program. If not, see <http://www.gnu.org/licenses/>.
+
+=cut
