@@ -1,13 +1,37 @@
-package Net::Fritz::IsNoError;
 use strict;
 use warnings;
+# Copyright (C) 2015  Christian Garbs <mitch@cgarbs.de>
+# Licensed under GNU GPL v2 or later.
+
+package Net::Fritz::IsNoError;
+# ABSTRACT: a L<Moo::Role> discerning all other L<Net::Fritz> objects from a L<Net::Fritz::Error> object
+$Net::Fritz::IsNoError::VERSION = 'v0.0.2';
 
 use Moo::Role;
 
+
+has error => ( is => 'ro', default => '' );
+
+
+sub errorcheck {
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Net::Fritz::IsNoError - a L<Moo::Role> discerning all other
-L<Net::Fritz> objects from a L<Net::Fritz::Error> object
+Net::Fritz::IsNoError - a L<Moo::Role> discerning all other L<Net::Fritz> objects from a L<Net::Fritz::Error> object
+
+=head1 VERSION
+
+version v0.0.2
 
 =head1 SYNOPSIS
 
@@ -48,10 +72,6 @@ L<Net::Fritz::Service> object instead).
 Returns an empty string to pass any C<if($obj-E<gt>error) { ... }>
 checks.
 
-=cut
-
-has error => ( is => 'ro', default => '' );
-
 =head1 METHODS
 
 =head2 errorcheck
@@ -59,28 +79,30 @@ has error => ( is => 'ro', default => '' );
 A no-op, so that calling C<$obj-E<gt>errorcheck> just succeeds and
 carries on.
 
-=cut
-
-sub errorcheck {
-}
-
-=head1 COPYRIGHT
-
-Copyright (C) 2015 by  Christian Garbs <mitch@cgarbs.de>
-
-=head1 LICENSE
-
-Licensed under GNU GPL v2 or later, see <http://www.gnu.org/licenses/gpl-2.0-standalone.html>
-
-=head1 AUTHOR
-
-Christian Garbs <mitch@cgarbs.de>
-
 =head1 SEE ALSO
 
 See L<Net::Fritz> for general information about this package,
 especially L<Net::Fritz/INTERFACE> for links to the other classes.
 
-=cut
+=head1 AUTHOR
 
-1;
+Christian Garbs <mitch@cgarbs.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2016 Christian Garbs
+
+This program is free software: you can redistribute it and/or modify it
+under the terms of the GNU General Public License as published by the Free
+Software Foundation, either version 2 of the License, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+more details.
+
+You should have received a copy of the GNU General Public License along
+with this program. If not, see <http://www.gnu.org/licenses/>.
+
+=cut
